selectiontools
==============

.. automodule:: abjad.tools.selectiontools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.selectiontools.ContiguousSelection.ContiguousSelection
      ~abjad.tools.selectiontools.Descendants.Descendants
      ~abjad.tools.selectiontools.Lineage.Lineage
      ~abjad.tools.selectiontools.LogicalTie.LogicalTie
      ~abjad.tools.selectiontools.Parentage.Parentage
      ~abjad.tools.selectiontools.Selection.Selection
      ~abjad.tools.selectiontools.SelectionInventory.SelectionInventory
      ~abjad.tools.selectiontools.SimultaneousSelection.SimultaneousSelection
      ~abjad.tools.selectiontools.SliceSelection.SliceSelection
      ~abjad.tools.selectiontools.VerticalMoment.VerticalMoment
